import re
import datetime
import time
import cgi
import sys

nb_colors = 8

logfile = '/home/elie/irclogs/freenode/#freeder.log'
if len(sys.argv) > 1:
	logfile = sys.argv[1]

msg = re.compile('^(\d\d):(\d\d) <(.*?)> (.*)$')
log_start = re.compile('^--- Log opened (.*)$')

base_time = datetime.timedelta(0, 0, 0)



def tuple_of_hue(hue):
	t = hue * 6.0
	if t < 1.0:
		return (1.0, t, 0.0)
	elif t < 2.0:
		return (2.0 - t, 1.0, 0.0)
	elif t < 3.0:
		return (0.0, 1.0, t - 2.0)
	elif t < 4.0:
		return (0.0, 4.0 - t, 1.0)
	elif t < 5.0:
		return (t - 4.0, 0.0, 1.0)
	else:
		return (1.0, 0.0, 6.0 - t)

def color_of_hue(hue):
	c = tuple_of_hue(hue)
	return int( ((c[0] * 256 + c[1]) * 256 + c[2]) * 255 )


def hex_of_color(c):
	return '#' + hex(c)[2:].zfill(6)


def hash_color(s, offset=0):
	# Replace bytearray(s) by s.encode() in Python 3
	return hex_of_color(color_of_hue(float((sum(bytearray(s)) + offset) % nb_colors) / nb_colors))

colorize_table = {}
def colorize(pseudo):
	if pseudo not in colorize_table:
		c = hash_color(pseudo)
		vals = list(colorize_table.values())
		colorize_table[pseudo] = c
	return '<span style="color:%s">%s</span>' % (colorize_table[pseudo], pseudo)


def format_time(t):
	short_time = t.strftime('%H:%M')
	long_time = t.strftime('%Y-%m-%d %H:%M')
	return '<div>%s</div><div class="longtime">%s</div>' % (short_time, long_time)

def format_msg(msg):
	msg = cgi.escape(msg)
	msg = re.sub('(https?://[^ ]*)', '<a href="\\1">\\1</a>', msg)
	return msg




with open('/home/elie/Prog/Python/irclog/begin.php', 'r') as begin:
	print(begin.read())


with open(logfile, 'r') as f:
	for l in f:
		m = msg.search(l)
		if m != None:
			t = base_time + datetime.timedelta(0, 0, 0, int(m.group(1)), int(m.group(2)))
			timestamp = time.mktime(t.timetuple())
			print('<?php if (%d < $max_time && %d >= $min_time) { ?>' % (timestamp, timestamp))
			print('<tr><td>%s</td><td>&lt;%s&gt;</td><td>%s</td></tr>' % (format_time(t), colorize(m.group(3)), format_msg(m.group(4))))
			#print('<?php } else { echo("<p>$max_time - %d = " . ($max_time - %d) . "</p>"); } ?>' % (timestamp, timestamp))
			print('<?php } ?>')
			
		m = log_start.search(l)
		if m != None:
			pass
			base_time = datetime.datetime.strptime(m.group(1), '%a %b %d %H:%M:%S %Y')

with open('/home/elie/Prog/Python/irclog/end.php', 'r') as end:
	print(end.read())

